@@ -174,7 +174,7 @@ class LogManager(object):
     # 加*是为了强制在调用此方法时候使用关键字传参，如果以位置传参强制报错，因为此方法后面的参数中间可能以后随时会增加更多参数，造成之前的使用位置传参的代码参数意义不匹配。
     # noinspection PyAttributeOutsideInit
     def get_logger_and_add_handlers(self, log_level_int: int = None, *, is_add_stream_handler=True,
-                                    do_not_use_color_handler=None, log_path='/pythonlogs',
+                                    do_not_use_color_handler=None, log_path=None,
                                     log_filename=None, log_file_size: int = None,
                                     mongo_url=None, is_add_elastic_handler=False, is_add_kafka_handler=False,
                                     ding_talk_token=None, ding_talk_time_interval=60,
@@ -210,6 +210,8 @@ class LogManager(object):
             log_filename = f'{self._logger_name}.log'
         if log_file_size is None:
             log_file_size = nb_log_config_default.LOG_FILE_SIZE
+        if log_path is None:
+            log_path = nb_log_config_default.LOG_PATH or '/pythonlogs'
         if formatter_template is None:
             formatter_template = nb_log_config_default.FORMATTER_KIND
 
@@ -451,158 +453,3 @@ class LoggerLevelSetterMixin:
         return self
 
 
-# noinspection PyMethodMayBeStatic,PyNestedDecorators,PyArgumentEqualDefault
-class _Test(unittest.TestCase):
-    # noinspection PyMissingOrEmptyDocstring
-    @classmethod
-    def tearDownClass(cls):
-        """
-
-        """
-        time.sleep(1)
-
-    @unittest.skip
-    def test_repeat_add_handlers_(self):
-        """测试重复添加handlers"""
-        LogManager('tests').get_logger_and_add_handlers(log_path='../logs', log_filename='tests.log')
-        LogManager('tests').get_logger_and_add_handlers(log_path='../logs', log_filename='tests.log')
-        LogManager('tests').get_logger_and_add_handlers(log_path='../logs', log_filename='tests.log')
-        test_log = LogManager('tests').get_logger_and_add_handlers(log_path='../logs', log_filename='tests.log')
-        print('下面这一句不会重复打印四次和写入日志四次')
-        time.sleep(1)
-        test_log.debug('这一句不会重复打印四次和写入日志四次')
-
-    @unittest.skip
-    def test_get_logger_without_hanlders(self):
-        """测试没有handlers的日志"""
-        log = LogManager('test2').get_logger_without_handlers()
-        print('下面这一句不会被打印')
-        time.sleep(1)
-        log.info('这一句不会被打印')
-
-    @unittest.skip
-    def test_add_handlers(self):
-        """这样可以在具体的地方任意写debug和info级别日志，只需要在总闸处规定级别就能过滤，很方便"""
-        LogManager('test3').get_logger_and_add_handlers(2)
-        log1 = LogManager('test3').get_logger_without_handlers()
-        print('下面这一句是info级别，可以被打印出来')
-        time.sleep(1)
-        log1.info('这一句是info级别，可以被打印出来')
-        print('下面这一句是debug级别，不能被打印出来')
-        time.sleep(1)
-        log1.debug('这一句是debug级别，不能被打印出来')
-
-    @unittest.skip
-    def test_only_write_log_to_file(self):  # NOQA
-        """只写入日志文件"""
-        log5 = LogManager('test5').get_logger_and_add_handlers(20)
-        log6 = LogManager('test6').get_logger_and_add_handlers(is_add_stream_handler=False, log_filename='test6.log')
-        print('下面这句话只写入文件')
-        log5.debug('这句话只写入文件')
-        log6.debug('这句话只写入文件')
-
-    @unittest.skip
-    def test_none(self):
-        # noinspection PyUnusedLocal
-        log1 = LogManager('log1').get_logger_and_add_handlers()
-        LogManager().get_logger_and_add_handlers()
-
-        LogManager().get_logger_and_add_handlers()
-        log1 = LogManager('log1').get_logger_and_add_handlers()
-        LogManager().get_logger_and_add_handlers()
-        LogManager('log1').get_logger_and_add_handlers(log_filename='test_none.log')
-        log1.debug('打印几次？')
-
-    @unittest.skip
-    def test_formater(self):
-        logger2 = LogManager('test_formater2').get_logger_and_add_handlers(formatter_template=6)
-        logger2.debug('测试日志模板2')
-        logger5 = LogManager('test_formater5').get_logger_and_add_handlers(formatter_template=5)
-        logger5.error('测试日志模板5')
-
-    @unittest.skip
-    def test_ding_talk(self):
-        logger = LogManager('testdinding').get_logger_and_add_handlers(
-            ding_talk_token=nb_log_config_default.DING_TALK_TOKEN,
-            ding_talk_time_interval=10)
-        logger.debug('啦啦啦德玛西亚1')
-        logger.debug('啦啦啦德玛西亚2')
-        time.sleep(10)
-        logger.debug('啦啦啦德玛西亚3')
-
-    @unittest.skip
-    def test_remove_handler(self):
-        logger = LogManager('test13').get_logger_and_add_handlers()
-        logger.debug('去掉coloerhandler前')
-        LogManager('test13').remove_handler_by_handler_class(ColorHandler)
-        logger.debug('去掉coloerhandler后，此记录不会被打印')
-
-    @unittest.skip
-    def test_logging(self):
-        # logging命名空间是root,会导致日志重复打印，不要直接用。
-        logger = LogManager('test14').get_logger_and_add_handlers(formatter_template=4)
-        logger.debug('xxxx')
-        logging.warning('yyyyyyy')
-        logger.warning('zzzzzzzzz')
-
-    @unittest.skip
-    def test_logger_level_setter_mixin(self):
-        """
-        测试可以设置日志级别的mixin类
-        :return:
-        """
-        print('测试非常流弊的print')
-
-        class A(LoggerMixin, LoggerLevelSetterMixin):
-            pass
-
-        a = A().set_log_level(20)
-        a.logger.debug('这句话不能被显示')  # 这句话不能被打印
-        a.logger.error('这句话可以显示')
-
-    # @unittest.skip
-    def test_color_and_mongo_hanlder(self):
-        """测试彩色日志和日志写入mongodb"""
-        very_nb_print('测试颜色和mongo')
-
-        # logger = LogManager('helloMongo', is_pycharm_2019=False).get_logger_and_add_handlers(mongo_url=app_config.connect_url, formatter_template=5)
-        logging.error('xxxx')
-        logger = LogManager('helloMongo').get_logger_and_add_handlers(formatter_template=5, is_add_elastic_handler=True)
-        logger.addHandler(ColorHandler())  # 由于打了强大的猴子补丁，无惧反复添加同种handler。
-        logger.addHandler(ColorHandler())
-        logger.addHandler(ColorHandler())
-        for i in range(1000000):
-            time.sleep(0.1)
-            logger.debug('一个debug级别的日志。' * 3)
-            logger.info('一个info级别的日志。' * 3)
-            logger.warning('一个warning级别的日志。' * 3)
-            logger.error('一个error级别的日志。' * 3)
-            logger.critical('一个critical级别的日志。' * 3)
-
-    @unittest.skip
-    def test_all_handlers(self):
-        logger = LogManager('hi').get_logger_and_add_handlers(log_filename='hi.log',
-                                                              ding_talk_token=nb_log_config_default.DING_TALK_TOKEN,
-                                                              mongo_url=nb_log_config_default.MONGO_URL,
-                                                              formatter_template=5)
-        logger.debug('测试多种handler')
-
-
-def test_multiprocess_file_handler():
-    t1 = time.time()
-    logger = LogManager('abcd').get_logger_and_add_handlers(is_add_stream_handler=False,
-                                                            log_filename='amulti_test99.log', log_file_size=200)
-    for i in range(1000000, 2000000):
-        # time.sleep(0.000001)
-        logger.debug(f'{i}a')
-        if i % 10000 == 0:
-            very_nb_print(i)
-    very_nb_print(time.time() - t1)
-    time.sleep(10)
-
-
-if __name__ == "__main__":
-    unittest.main()
-    # from multiprocessing import Process
-    #
-    # [Process(target=test_multiprocess_file_handler).start() for _ in range(10)]
